Class: Aws::ComprehendMedical::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::ComprehendMedical::Client
- Includes:
- Aws::ClientStubs
- Defined in:
- lib/aws-sdk-comprehendmedical/client.rb
Overview
An API client for ComprehendMedical. To construct a client, you need to configure a :region and :credentials.
client = Aws::ComprehendMedical::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#describe_entities_detection_v2_job(params = {}) ⇒ Types::DescribeEntitiesDetectionV2JobResponse
Gets the properties associated with a medical entities detection job.
-
#describe_icd10cm_inference_job(params = {}) ⇒ Types::DescribeICD10CMInferenceJobResponse
Gets the properties associated with an InferICD10CM job.
-
#describe_phi_detection_job(params = {}) ⇒ Types::DescribePHIDetectionJobResponse
Gets the properties associated with a protected health information (PHI) detection job.
-
#describe_rx_norm_inference_job(params = {}) ⇒ Types::DescribeRxNormInferenceJobResponse
Gets the properties associated with an InferRxNorm job.
-
#describe_snomedct_inference_job(params = {}) ⇒ Types::DescribeSNOMEDCTInferenceJobResponse
Gets the properties associated with an InferSNOMEDCT job.
-
#detect_entities(params = {}) ⇒ Types::DetectEntitiesResponse
The
DetectEntitiesoperation is deprecated. -
#detect_entities_v2(params = {}) ⇒ Types::DetectEntitiesV2Response
Inspects the clinical text for a variety of medical entities and returns specific information about them such as entity category, location, and confidence score on that information.
-
#detect_phi(params = {}) ⇒ Types::DetectPHIResponse
Inspects the clinical text for protected health information (PHI) entities and returns the entity category, location, and confidence score for each entity.
-
#infer_icd10cm(params = {}) ⇒ Types::InferICD10CMResponse
InferICD10CM detects medical conditions as entities listed in a patient record and links those entities to normalized concept identifiers in the ICD-10-CM knowledge base from the Centers for Disease Control.
-
#infer_rx_norm(params = {}) ⇒ Types::InferRxNormResponse
InferRxNorm detects medications as entities listed in a patient record and links to the normalized concept identifiers in the RxNorm database from the National Library of Medicine.
-
#infer_snomedct(params = {}) ⇒ Types::InferSNOMEDCTResponse
InferSNOMEDCT detects possible medical concepts as entities and links them to codes from the Systematized Nomenclature of Medicine, Clinical Terms (SNOMED-CT) ontology.
-
#list_entities_detection_v2_jobs(params = {}) ⇒ Types::ListEntitiesDetectionV2JobsResponse
Gets a list of medical entity detection jobs that you have submitted.
-
#list_icd10cm_inference_jobs(params = {}) ⇒ Types::ListICD10CMInferenceJobsResponse
Gets a list of InferICD10CM jobs that you have submitted.
-
#list_phi_detection_jobs(params = {}) ⇒ Types::ListPHIDetectionJobsResponse
Gets a list of protected health information (PHI) detection jobs you have submitted.
-
#list_rx_norm_inference_jobs(params = {}) ⇒ Types::ListRxNormInferenceJobsResponse
Gets a list of InferRxNorm jobs that you have submitted.
-
#list_snomedct_inference_jobs(params = {}) ⇒ Types::ListSNOMEDCTInferenceJobsResponse
Gets a list of InferSNOMEDCT jobs a user has submitted.
-
#start_entities_detection_v2_job(params = {}) ⇒ Types::StartEntitiesDetectionV2JobResponse
Starts an asynchronous medical entity detection job for a collection of documents.
-
#start_icd10cm_inference_job(params = {}) ⇒ Types::StartICD10CMInferenceJobResponse
Starts an asynchronous job to detect medical conditions and link them to the ICD-10-CM ontology.
-
#start_phi_detection_job(params = {}) ⇒ Types::StartPHIDetectionJobResponse
Starts an asynchronous job to detect protected health information (PHI).
-
#start_rx_norm_inference_job(params = {}) ⇒ Types::StartRxNormInferenceJobResponse
Starts an asynchronous job to detect medication entities and link them to the RxNorm ontology.
-
#start_snomedct_inference_job(params = {}) ⇒ Types::StartSNOMEDCTInferenceJobResponse
Starts an asynchronous job to detect medical concepts and link them to the SNOMED-CT ontology.
-
#stop_entities_detection_v2_job(params = {}) ⇒ Types::StopEntitiesDetectionV2JobResponse
Stops a medical entities detection job in progress.
-
#stop_icd10cm_inference_job(params = {}) ⇒ Types::StopICD10CMInferenceJobResponse
Stops an InferICD10CM inference job in progress.
-
#stop_phi_detection_job(params = {}) ⇒ Types::StopPHIDetectionJobResponse
Stops a protected health information (PHI) detection job in progress.
-
#stop_rx_norm_inference_job(params = {}) ⇒ Types::StopRxNormInferenceJobResponse
Stops an InferRxNorm inference job in progress.
-
#stop_snomedct_inference_job(params = {}) ⇒ Types::StopSNOMEDCTInferenceJobResponse
Stops an InferSNOMEDCT inference job in progress.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
480 481 482 |
# File 'lib/aws-sdk-comprehendmedical/client.rb', line 480 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1972 1973 1974 |
# File 'lib/aws-sdk-comprehendmedical/client.rb', line 1972 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1975 1976 1977 |
# File 'lib/aws-sdk-comprehendmedical/client.rb', line 1975 def errors_module Errors end |
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1945 1946 1947 1948 1949 1950 1951 1952 1953 1954 1955 1956 1957 1958 1959 1960 1961 |
# File 'lib/aws-sdk-comprehendmedical/client.rb', line 1945 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::ComprehendMedical') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-comprehendmedical' context[:gem_version] = '1.80.0' Seahorse::Client::Request.new(handlers, context) end |
#describe_entities_detection_v2_job(params = {}) ⇒ Types::DescribeEntitiesDetectionV2JobResponse
Gets the properties associated with a medical entities detection job. Use this operation to get the status of a detection job.
527 528 529 530 |
# File 'lib/aws-sdk-comprehendmedical/client.rb', line 527 def describe_entities_detection_v2_job(params = {}, = {}) req = build_request(:describe_entities_detection_v2_job, params) req.send_request() end |
#describe_icd10cm_inference_job(params = {}) ⇒ Types::DescribeICD10CMInferenceJobResponse
Gets the properties associated with an InferICD10CM job. Use this operation to get the status of an inference job.
573 574 575 576 |
# File 'lib/aws-sdk-comprehendmedical/client.rb', line 573 def describe_icd10cm_inference_job(params = {}, = {}) req = build_request(:describe_icd10cm_inference_job, params) req.send_request() end |
#describe_phi_detection_job(params = {}) ⇒ Types::DescribePHIDetectionJobResponse
Gets the properties associated with a protected health information (PHI) detection job. Use this operation to get the status of a detection job.
620 621 622 623 |
# File 'lib/aws-sdk-comprehendmedical/client.rb', line 620 def describe_phi_detection_job(params = {}, = {}) req = build_request(:describe_phi_detection_job, params) req.send_request() end |
#describe_rx_norm_inference_job(params = {}) ⇒ Types::DescribeRxNormInferenceJobResponse
Gets the properties associated with an InferRxNorm job. Use this operation to get the status of an inference job.
666 667 668 669 |
# File 'lib/aws-sdk-comprehendmedical/client.rb', line 666 def describe_rx_norm_inference_job(params = {}, = {}) req = build_request(:describe_rx_norm_inference_job, params) req.send_request() end |
#describe_snomedct_inference_job(params = {}) ⇒ Types::DescribeSNOMEDCTInferenceJobResponse
Gets the properties associated with an InferSNOMEDCT job. Use this operation to get the status of an inference job.
712 713 714 715 |
# File 'lib/aws-sdk-comprehendmedical/client.rb', line 712 def describe_snomedct_inference_job(params = {}, = {}) req = build_request(:describe_snomedct_inference_job, params) req.send_request() end |
#detect_entities(params = {}) ⇒ Types::DetectEntitiesResponse
The DetectEntities operation is deprecated. You should use the DetectEntitiesV2 operation instead.
Inspects the clinical text for a variety of medical entities and returns specific information about them such as entity category, location, and confidence score on that information.
788 789 790 791 |
# File 'lib/aws-sdk-comprehendmedical/client.rb', line 788 def detect_entities(params = {}, = {}) req = build_request(:detect_entities, params) req.send_request() end |
#detect_entities_v2(params = {}) ⇒ Types::DetectEntitiesV2Response
Inspects the clinical text for a variety of medical entities and returns specific information about them such as entity category, location, and confidence score on that information. Amazon Comprehend Medical only detects medical entities in English language texts.
The DetectEntitiesV2 operation replaces the DetectEntities operation. This new action uses a different model for determining the entities in your medical text and changes the way that some entities are returned in the output. You should use the DetectEntitiesV2 operation in all new applications.
The DetectEntitiesV2 operation returns the Acuity and Direction entities as attributes instead of types.
871 872 873 874 |
# File 'lib/aws-sdk-comprehendmedical/client.rb', line 871 def detect_entities_v2(params = {}, = {}) req = build_request(:detect_entities_v2, params) req.send_request() end |
#detect_phi(params = {}) ⇒ Types::DetectPHIResponse
Inspects the clinical text for protected health information (PHI) entities and returns the entity category, location, and confidence score for each entity. Amazon Comprehend Medical only detects entities in English language texts.
930 931 932 933 |
# File 'lib/aws-sdk-comprehendmedical/client.rb', line 930 def detect_phi(params = {}, = {}) req = build_request(:detect_phi, params) req.send_request() end |
#infer_icd10cm(params = {}) ⇒ Types::InferICD10CMResponse
InferICD10CM detects medical conditions as entities listed in a patient record and links those entities to normalized concept identifiers in the ICD-10-CM knowledge base from the Centers for Disease Control. Amazon Comprehend Medical only detects medical entities in English language texts.
993 994 995 996 |
# File 'lib/aws-sdk-comprehendmedical/client.rb', line 993 def infer_icd10cm(params = {}, = {}) req = build_request(:infer_icd10cm, params) req.send_request() end |
#infer_rx_norm(params = {}) ⇒ Types::InferRxNormResponse
InferRxNorm detects medications as entities listed in a patient record and links to the normalized concept identifiers in the RxNorm database from the National Library of Medicine. Amazon Comprehend Medical only detects medical entities in English language texts.
1053 1054 1055 1056 |
# File 'lib/aws-sdk-comprehendmedical/client.rb', line 1053 def infer_rx_norm(params = {}, = {}) req = build_request(:infer_rx_norm, params) req.send_request() end |
#infer_snomedct(params = {}) ⇒ Types::InferSNOMEDCTResponse
InferSNOMEDCT detects possible medical concepts as entities and links them to codes from the Systematized Nomenclature of Medicine, Clinical Terms (SNOMED-CT) ontology
1124 1125 1126 1127 |
# File 'lib/aws-sdk-comprehendmedical/client.rb', line 1124 def infer_snomedct(params = {}, = {}) req = build_request(:infer_snomedct, params) req.send_request() end |
#list_entities_detection_v2_jobs(params = {}) ⇒ Types::ListEntitiesDetectionV2JobsResponse
Gets a list of medical entity detection jobs that you have submitted.
1186 1187 1188 1189 |
# File 'lib/aws-sdk-comprehendmedical/client.rb', line 1186 def list_entities_detection_v2_jobs(params = {}, = {}) req = build_request(:list_entities_detection_v2_jobs, params) req.send_request() end |
#list_icd10cm_inference_jobs(params = {}) ⇒ Types::ListICD10CMInferenceJobsResponse
Gets a list of InferICD10CM jobs that you have submitted.
1248 1249 1250 1251 |
# File 'lib/aws-sdk-comprehendmedical/client.rb', line 1248 def list_icd10cm_inference_jobs(params = {}, = {}) req = build_request(:list_icd10cm_inference_jobs, params) req.send_request() end |
#list_phi_detection_jobs(params = {}) ⇒ Types::ListPHIDetectionJobsResponse
Gets a list of protected health information (PHI) detection jobs you have submitted.
1311 1312 1313 1314 |
# File 'lib/aws-sdk-comprehendmedical/client.rb', line 1311 def list_phi_detection_jobs(params = {}, = {}) req = build_request(:list_phi_detection_jobs, params) req.send_request() end |
#list_rx_norm_inference_jobs(params = {}) ⇒ Types::ListRxNormInferenceJobsResponse
Gets a list of InferRxNorm jobs that you have submitted.
1372 1373 1374 1375 |
# File 'lib/aws-sdk-comprehendmedical/client.rb', line 1372 def list_rx_norm_inference_jobs(params = {}, = {}) req = build_request(:list_rx_norm_inference_jobs, params) req.send_request() end |
#list_snomedct_inference_jobs(params = {}) ⇒ Types::ListSNOMEDCTInferenceJobsResponse
Gets a list of InferSNOMEDCT jobs a user has submitted.
1432 1433 1434 1435 |
# File 'lib/aws-sdk-comprehendmedical/client.rb', line 1432 def list_snomedct_inference_jobs(params = {}, = {}) req = build_request(:list_snomedct_inference_jobs, params) req.send_request() end |
#start_entities_detection_v2_job(params = {}) ⇒ Types::StartEntitiesDetectionV2JobResponse
Starts an asynchronous medical entity detection job for a collection of documents. Use the DescribeEntitiesDetectionV2Job operation to track the status of a job.
1508 1509 1510 1511 |
# File 'lib/aws-sdk-comprehendmedical/client.rb', line 1508 def start_entities_detection_v2_job(params = {}, = {}) req = build_request(:start_entities_detection_v2_job, params) req.send_request() end |
#start_icd10cm_inference_job(params = {}) ⇒ Types::StartICD10CMInferenceJobResponse
Starts an asynchronous job to detect medical conditions and link them to the ICD-10-CM ontology. Use the DescribeICD10CMInferenceJob operation to track the status of a job.
1581 1582 1583 1584 |
# File 'lib/aws-sdk-comprehendmedical/client.rb', line 1581 def start_icd10cm_inference_job(params = {}, = {}) req = build_request(:start_icd10cm_inference_job, params) req.send_request() end |
#start_phi_detection_job(params = {}) ⇒ Types::StartPHIDetectionJobResponse
Starts an asynchronous job to detect protected health information (PHI). Use the DescribePHIDetectionJob operation to track the status of a job.
1654 1655 1656 1657 |
# File 'lib/aws-sdk-comprehendmedical/client.rb', line 1654 def start_phi_detection_job(params = {}, = {}) req = build_request(:start_phi_detection_job, params) req.send_request() end |
#start_rx_norm_inference_job(params = {}) ⇒ Types::StartRxNormInferenceJobResponse
Starts an asynchronous job to detect medication entities and link them to the RxNorm ontology. Use the DescribeRxNormInferenceJob operation to track the status of a job.
1727 1728 1729 1730 |
# File 'lib/aws-sdk-comprehendmedical/client.rb', line 1727 def start_rx_norm_inference_job(params = {}, = {}) req = build_request(:start_rx_norm_inference_job, params) req.send_request() end |
#start_snomedct_inference_job(params = {}) ⇒ Types::StartSNOMEDCTInferenceJobResponse
Starts an asynchronous job to detect medical concepts and link them to the SNOMED-CT ontology. Use the DescribeSNOMEDCTInferenceJob operation to track the status of a job.
1796 1797 1798 1799 |
# File 'lib/aws-sdk-comprehendmedical/client.rb', line 1796 def start_snomedct_inference_job(params = {}, = {}) req = build_request(:start_snomedct_inference_job, params) req.send_request() end |
#stop_entities_detection_v2_job(params = {}) ⇒ Types::StopEntitiesDetectionV2JobResponse
Stops a medical entities detection job in progress.
1824 1825 1826 1827 |
# File 'lib/aws-sdk-comprehendmedical/client.rb', line 1824 def stop_entities_detection_v2_job(params = {}, = {}) req = build_request(:stop_entities_detection_v2_job, params) req.send_request() end |
#stop_icd10cm_inference_job(params = {}) ⇒ Types::StopICD10CMInferenceJobResponse
Stops an InferICD10CM inference job in progress.
1852 1853 1854 1855 |
# File 'lib/aws-sdk-comprehendmedical/client.rb', line 1852 def stop_icd10cm_inference_job(params = {}, = {}) req = build_request(:stop_icd10cm_inference_job, params) req.send_request() end |
#stop_phi_detection_job(params = {}) ⇒ Types::StopPHIDetectionJobResponse
Stops a protected health information (PHI) detection job in progress.
1880 1881 1882 1883 |
# File 'lib/aws-sdk-comprehendmedical/client.rb', line 1880 def stop_phi_detection_job(params = {}, = {}) req = build_request(:stop_phi_detection_job, params) req.send_request() end |
#stop_rx_norm_inference_job(params = {}) ⇒ Types::StopRxNormInferenceJobResponse
Stops an InferRxNorm inference job in progress.
1908 1909 1910 1911 |
# File 'lib/aws-sdk-comprehendmedical/client.rb', line 1908 def stop_rx_norm_inference_job(params = {}, = {}) req = build_request(:stop_rx_norm_inference_job, params) req.send_request() end |
#stop_snomedct_inference_job(params = {}) ⇒ Types::StopSNOMEDCTInferenceJobResponse
Stops an InferSNOMEDCT inference job in progress.
1936 1937 1938 1939 |
# File 'lib/aws-sdk-comprehendmedical/client.rb', line 1936 def stop_snomedct_inference_job(params = {}, = {}) req = build_request(:stop_snomedct_inference_job, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1965 1966 1967 |
# File 'lib/aws-sdk-comprehendmedical/client.rb', line 1965 def waiter_names [] end |