Class: Aws::ComprehendMedical::Types::StartSNOMEDCTInferenceJobRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-comprehendmedical/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#client_request_tokenString

A unique identifier for the request. If you don’t set the client request token, Amazon Comprehend Medical generates one.

**A suitable default value is auto-generated.** You should normally not need to pass this option.

Returns:



1951
1952
1953
1954
1955
1956
1957
1958
1959
1960
1961
# File 'lib/aws-sdk-comprehendmedical/types.rb', line 1951

class StartSNOMEDCTInferenceJobRequest < Struct.new(
  :input_data_config,
  :output_data_config,
  :data_access_role_arn,
  :job_name,
  :client_request_token,
  :kms_key,
  :language_code)
  SENSITIVE = []
  include Aws::Structure
end

#data_access_role_arnString

The Amazon Resource Name (ARN) of the AWS Identity and Access Management (IAM) role that grants Amazon Comprehend Medical read access to your input data.

Returns:



1951
1952
1953
1954
1955
1956
1957
1958
1959
1960
1961
# File 'lib/aws-sdk-comprehendmedical/types.rb', line 1951

class StartSNOMEDCTInferenceJobRequest < Struct.new(
  :input_data_config,
  :output_data_config,
  :data_access_role_arn,
  :job_name,
  :client_request_token,
  :kms_key,
  :language_code)
  SENSITIVE = []
  include Aws::Structure
end

#input_data_configTypes::InputDataConfig

The input properties for an entities detection job. This includes the name of the S3 bucket and the path to the files to be analyzed.

Returns:



1951
1952
1953
1954
1955
1956
1957
1958
1959
1960
1961
# File 'lib/aws-sdk-comprehendmedical/types.rb', line 1951

class StartSNOMEDCTInferenceJobRequest < Struct.new(
  :input_data_config,
  :output_data_config,
  :data_access_role_arn,
  :job_name,
  :client_request_token,
  :kms_key,
  :language_code)
  SENSITIVE = []
  include Aws::Structure
end

#job_nameString

The user generated name the asynchronous InferSNOMEDCT job.

Returns:



1951
1952
1953
1954
1955
1956
1957
1958
1959
1960
1961
# File 'lib/aws-sdk-comprehendmedical/types.rb', line 1951

class StartSNOMEDCTInferenceJobRequest < Struct.new(
  :input_data_config,
  :output_data_config,
  :data_access_role_arn,
  :job_name,
  :client_request_token,
  :kms_key,
  :language_code)
  SENSITIVE = []
  include Aws::Structure
end

#kms_keyString

An AWS Key Management Service key used to encrypt your output files. If you do not specify a key, the files are written in plain text.

Returns:



1951
1952
1953
1954
1955
1956
1957
1958
1959
1960
1961
# File 'lib/aws-sdk-comprehendmedical/types.rb', line 1951

class StartSNOMEDCTInferenceJobRequest < Struct.new(
  :input_data_config,
  :output_data_config,
  :data_access_role_arn,
  :job_name,
  :client_request_token,
  :kms_key,
  :language_code)
  SENSITIVE = []
  include Aws::Structure
end

#language_codeString

The language of the input documents. All documents must be in the same language.

Returns:



1951
1952
1953
1954
1955
1956
1957
1958
1959
1960
1961
# File 'lib/aws-sdk-comprehendmedical/types.rb', line 1951

class StartSNOMEDCTInferenceJobRequest < Struct.new(
  :input_data_config,
  :output_data_config,
  :data_access_role_arn,
  :job_name,
  :client_request_token,
  :kms_key,
  :language_code)
  SENSITIVE = []
  include Aws::Structure
end

#output_data_configTypes::OutputDataConfig

The output properties for a detection job.

Returns:



1951
1952
1953
1954
1955
1956
1957
1958
1959
1960
1961
# File 'lib/aws-sdk-comprehendmedical/types.rb', line 1951

class StartSNOMEDCTInferenceJobRequest < Struct.new(
  :input_data_config,
  :output_data_config,
  :data_access_role_arn,
  :job_name,
  :client_request_token,
  :kms_key,
  :language_code)
  SENSITIVE = []
  include Aws::Structure
end