Class: Aws::ComprehendMedical::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::ComprehendMedical::Client
- Includes:
- Aws::ClientStubs
- Defined in:
- lib/aws-sdk-comprehendmedical/client.rb,
sig/client.rbs
Overview
An API client for ComprehendMedical. To construct a client, you need to configure a :region and :credentials.
client = Aws::ComprehendMedical::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _DescribeEntitiesDetectionV2JobResponseSuccess, _DescribeICD10CMInferenceJobResponseSuccess, _DescribePHIDetectionJobResponseSuccess, _DescribeRxNormInferenceJobResponseSuccess, _DescribeSNOMEDCTInferenceJobResponseSuccess, _DetectEntitiesResponseSuccess, _DetectEntitiesV2ResponseSuccess, _DetectPHIResponseSuccess, _InferICD10CMResponseSuccess, _InferRxNormResponseSuccess, _InferSNOMEDCTResponseSuccess, _ListEntitiesDetectionV2JobsResponseSuccess, _ListICD10CMInferenceJobsResponseSuccess, _ListPHIDetectionJobsResponseSuccess, _ListRxNormInferenceJobsResponseSuccess, _ListSNOMEDCTInferenceJobsResponseSuccess, _StartEntitiesDetectionV2JobResponseSuccess, _StartICD10CMInferenceJobResponseSuccess, _StartPHIDetectionJobResponseSuccess, _StartRxNormInferenceJobResponseSuccess, _StartSNOMEDCTInferenceJobResponseSuccess, _StopEntitiesDetectionV2JobResponseSuccess, _StopICD10CMInferenceJobResponseSuccess, _StopPHIDetectionJobResponseSuccess, _StopRxNormInferenceJobResponseSuccess, _StopSNOMEDCTInferenceJobResponseSuccess
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#describe_entities_detection_v2_job(params = {}) ⇒ Types::DescribeEntitiesDetectionV2JobResponse
Gets the properties associated with a medical entities detection job.
-
#describe_icd10cm_inference_job(params = {}) ⇒ Types::DescribeICD10CMInferenceJobResponse
Gets the properties associated with an InferICD10CM job.
-
#describe_phi_detection_job(params = {}) ⇒ Types::DescribePHIDetectionJobResponse
Gets the properties associated with a protected health information (PHI) detection job.
-
#describe_rx_norm_inference_job(params = {}) ⇒ Types::DescribeRxNormInferenceJobResponse
Gets the properties associated with an InferRxNorm job.
-
#describe_snomedct_inference_job(params = {}) ⇒ Types::DescribeSNOMEDCTInferenceJobResponse
Gets the properties associated with an InferSNOMEDCT job.
-
#detect_entities(params = {}) ⇒ Types::DetectEntitiesResponse
The
DetectEntitiesoperation is deprecated. -
#detect_entities_v2(params = {}) ⇒ Types::DetectEntitiesV2Response
Inspects the clinical text for a variety of medical entities and returns specific information about them such as entity category, location, and confidence score on that information.
-
#detect_phi(params = {}) ⇒ Types::DetectPHIResponse
Inspects the clinical text for protected health information (PHI) entities and returns the entity category, location, and confidence score for each entity.
-
#infer_icd10cm(params = {}) ⇒ Types::InferICD10CMResponse
InferICD10CM detects medical conditions as entities listed in a patient record and links those entities to normalized concept identifiers in the ICD-10-CM knowledge base from the Centers for Disease Control.
-
#infer_rx_norm(params = {}) ⇒ Types::InferRxNormResponse
InferRxNorm detects medications as entities listed in a patient record and links to the normalized concept identifiers in the RxNorm database from the National Library of Medicine.
-
#infer_snomedct(params = {}) ⇒ Types::InferSNOMEDCTResponse
InferSNOMEDCT detects possible medical concepts as entities and links them to codes from the Systematized Nomenclature of Medicine, Clinical Terms (SNOMED-CT) ontology.
-
#list_entities_detection_v2_jobs(params = {}) ⇒ Types::ListEntitiesDetectionV2JobsResponse
Gets a list of medical entity detection jobs that you have submitted.
-
#list_icd10cm_inference_jobs(params = {}) ⇒ Types::ListICD10CMInferenceJobsResponse
Gets a list of InferICD10CM jobs that you have submitted.
-
#list_phi_detection_jobs(params = {}) ⇒ Types::ListPHIDetectionJobsResponse
Gets a list of protected health information (PHI) detection jobs you have submitted.
-
#list_rx_norm_inference_jobs(params = {}) ⇒ Types::ListRxNormInferenceJobsResponse
Gets a list of InferRxNorm jobs that you have submitted.
-
#list_snomedct_inference_jobs(params = {}) ⇒ Types::ListSNOMEDCTInferenceJobsResponse
Gets a list of InferSNOMEDCT jobs a user has submitted.
-
#start_entities_detection_v2_job(params = {}) ⇒ Types::StartEntitiesDetectionV2JobResponse
Starts an asynchronous medical entity detection job for a collection of documents.
-
#start_icd10cm_inference_job(params = {}) ⇒ Types::StartICD10CMInferenceJobResponse
Starts an asynchronous job to detect medical conditions and link them to the ICD-10-CM ontology.
-
#start_phi_detection_job(params = {}) ⇒ Types::StartPHIDetectionJobResponse
Starts an asynchronous job to detect protected health information (PHI).
-
#start_rx_norm_inference_job(params = {}) ⇒ Types::StartRxNormInferenceJobResponse
Starts an asynchronous job to detect medication entities and link them to the RxNorm ontology.
-
#start_snomedct_inference_job(params = {}) ⇒ Types::StartSNOMEDCTInferenceJobResponse
Starts an asynchronous job to detect medical concepts and link them to the SNOMED-CT ontology.
-
#stop_entities_detection_v2_job(params = {}) ⇒ Types::StopEntitiesDetectionV2JobResponse
Stops a medical entities detection job in progress.
-
#stop_icd10cm_inference_job(params = {}) ⇒ Types::StopICD10CMInferenceJobResponse
Stops an InferICD10CM inference job in progress.
-
#stop_phi_detection_job(params = {}) ⇒ Types::StopPHIDetectionJobResponse
Stops a protected health information (PHI) detection job in progress.
-
#stop_rx_norm_inference_job(params = {}) ⇒ Types::StopRxNormInferenceJobResponse
Stops an InferRxNorm inference job in progress.
-
#stop_snomedct_inference_job(params = {}) ⇒ Types::StopSNOMEDCTInferenceJobResponse
Stops an InferSNOMEDCT inference job in progress.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
478 479 480 |
# File 'lib/aws-sdk-comprehendmedical/client.rb', line 478 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1970 1971 1972 |
# File 'lib/aws-sdk-comprehendmedical/client.rb', line 1970 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1973 1974 1975 |
# File 'lib/aws-sdk-comprehendmedical/client.rb', line 1973 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14
def self.new: (
|
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1943 1944 1945 1946 1947 1948 1949 1950 1951 1952 1953 1954 1955 1956 1957 1958 1959 |
# File 'lib/aws-sdk-comprehendmedical/client.rb', line 1943 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::ComprehendMedical') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-comprehendmedical' context[:gem_version] = '1.85.0' Seahorse::Client::Request.new(handlers, context) end |
#describe_entities_detection_v2_job(params = {}) ⇒ Types::DescribeEntitiesDetectionV2JobResponse
Gets the properties associated with a medical entities detection job. Use this operation to get the status of a detection job.
87 |
# File 'sig/client.rbs', line 87
def describe_entities_detection_v2_job: (
|
#describe_icd10cm_inference_job(params = {}) ⇒ Types::DescribeICD10CMInferenceJobResponse
Gets the properties associated with an InferICD10CM job. Use this operation to get the status of an inference job.
97 |
# File 'sig/client.rbs', line 97
def describe_icd10cm_inference_job: (
|
#describe_phi_detection_job(params = {}) ⇒ Types::DescribePHIDetectionJobResponse
Gets the properties associated with a protected health information (PHI) detection job. Use this operation to get the status of a detection job.
107 |
# File 'sig/client.rbs', line 107
def describe_phi_detection_job: (
|
#describe_rx_norm_inference_job(params = {}) ⇒ Types::DescribeRxNormInferenceJobResponse
Gets the properties associated with an InferRxNorm job. Use this operation to get the status of an inference job.
117 |
# File 'sig/client.rbs', line 117
def describe_rx_norm_inference_job: (
|
#describe_snomedct_inference_job(params = {}) ⇒ Types::DescribeSNOMEDCTInferenceJobResponse
Gets the properties associated with an InferSNOMEDCT job. Use this operation to get the status of an inference job.
127 |
# File 'sig/client.rbs', line 127
def describe_snomedct_inference_job: (
|
#detect_entities(params = {}) ⇒ Types::DetectEntitiesResponse
The DetectEntities operation is deprecated. You should use the
DetectEntitiesV2 operation instead.
Inspects the clinical text for a variety of medical entities and returns specific information about them such as entity category, location, and confidence score on that information.
140 |
# File 'sig/client.rbs', line 140
def detect_entities: (
|
#detect_entities_v2(params = {}) ⇒ Types::DetectEntitiesV2Response
Inspects the clinical text for a variety of medical entities and returns specific information about them such as entity category, location, and confidence score on that information. Amazon Comprehend Medical only detects medical entities in English language texts.
The DetectEntitiesV2 operation replaces the DetectEntities
operation. This new action uses a different model for determining the
entities in your medical text and changes the way that some entities
are returned in the output. You should use the DetectEntitiesV2
operation in all new applications.
The DetectEntitiesV2 operation returns the Acuity and Direction
entities as attributes instead of types.
153 |
# File 'sig/client.rbs', line 153
def detect_entities_v2: (
|
#detect_phi(params = {}) ⇒ Types::DetectPHIResponse
Inspects the clinical text for protected health information (PHI) entities and returns the entity category, location, and confidence score for each entity. Amazon Comprehend Medical only detects entities in English language texts.
165 |
# File 'sig/client.rbs', line 165
def detect_phi: (
|
#infer_icd10cm(params = {}) ⇒ Types::InferICD10CMResponse
InferICD10CM detects medical conditions as entities listed in a patient record and links those entities to normalized concept identifiers in the ICD-10-CM knowledge base from the Centers for Disease Control. Amazon Comprehend Medical only detects medical entities in English language texts.
177 |
# File 'sig/client.rbs', line 177
def infer_icd10cm: (
|
#infer_rx_norm(params = {}) ⇒ Types::InferRxNormResponse
InferRxNorm detects medications as entities listed in a patient record and links to the normalized concept identifiers in the RxNorm database from the National Library of Medicine. Amazon Comprehend Medical only detects medical entities in English language texts.
189 |
# File 'sig/client.rbs', line 189
def infer_rx_norm: (
|
#infer_snomedct(params = {}) ⇒ Types::InferSNOMEDCTResponse
InferSNOMEDCT detects possible medical concepts as entities and links them to codes from the Systematized Nomenclature of Medicine, Clinical Terms (SNOMED-CT) ontology
203 |
# File 'sig/client.rbs', line 203
def infer_snomedct: (
|
#list_entities_detection_v2_jobs(params = {}) ⇒ Types::ListEntitiesDetectionV2JobsResponse
Gets a list of medical entity detection jobs that you have submitted.
214 |
# File 'sig/client.rbs', line 214
def list_entities_detection_v2_jobs: (
|
#list_icd10cm_inference_jobs(params = {}) ⇒ Types::ListICD10CMInferenceJobsResponse
Gets a list of InferICD10CM jobs that you have submitted.
232 |
# File 'sig/client.rbs', line 232
def list_icd10cm_inference_jobs: (
|
#list_phi_detection_jobs(params = {}) ⇒ Types::ListPHIDetectionJobsResponse
Gets a list of protected health information (PHI) detection jobs you have submitted.
250 |
# File 'sig/client.rbs', line 250
def list_phi_detection_jobs: (
|
#list_rx_norm_inference_jobs(params = {}) ⇒ Types::ListRxNormInferenceJobsResponse
Gets a list of InferRxNorm jobs that you have submitted.
268 |
# File 'sig/client.rbs', line 268
def list_rx_norm_inference_jobs: (
|
#list_snomedct_inference_jobs(params = {}) ⇒ Types::ListSNOMEDCTInferenceJobsResponse
Gets a list of InferSNOMEDCT jobs a user has submitted.
286 |
# File 'sig/client.rbs', line 286
def list_snomedct_inference_jobs: (
|
#start_entities_detection_v2_job(params = {}) ⇒ Types::StartEntitiesDetectionV2JobResponse
Starts an asynchronous medical entity detection job for a collection
of documents. Use the DescribeEntitiesDetectionV2Job operation to
track the status of a job.
303 |
# File 'sig/client.rbs', line 303
def start_entities_detection_v2_job: (
|
#start_icd10cm_inference_job(params = {}) ⇒ Types::StartICD10CMInferenceJobResponse
Starts an asynchronous job to detect medical conditions and link them
to the ICD-10-CM ontology. Use the DescribeICD10CMInferenceJob
operation to track the status of a job.
325 |
# File 'sig/client.rbs', line 325
def start_icd10cm_inference_job: (
|
#start_phi_detection_job(params = {}) ⇒ Types::StartPHIDetectionJobResponse
Starts an asynchronous job to detect protected health information
(PHI). Use the DescribePHIDetectionJob operation to track the status
of a job.
347 |
# File 'sig/client.rbs', line 347
def start_phi_detection_job: (
|
#start_rx_norm_inference_job(params = {}) ⇒ Types::StartRxNormInferenceJobResponse
Starts an asynchronous job to detect medication entities and link them
to the RxNorm ontology. Use the DescribeRxNormInferenceJob operation
to track the status of a job.
369 |
# File 'sig/client.rbs', line 369
def start_rx_norm_inference_job: (
|
#start_snomedct_inference_job(params = {}) ⇒ Types::StartSNOMEDCTInferenceJobResponse
Starts an asynchronous job to detect medical concepts and link them to the SNOMED-CT ontology. Use the DescribeSNOMEDCTInferenceJob operation to track the status of a job.
391 |
# File 'sig/client.rbs', line 391
def start_snomedct_inference_job: (
|
#stop_entities_detection_v2_job(params = {}) ⇒ Types::StopEntitiesDetectionV2JobResponse
Stops a medical entities detection job in progress.
413 |
# File 'sig/client.rbs', line 413
def stop_entities_detection_v2_job: (
|
#stop_icd10cm_inference_job(params = {}) ⇒ Types::StopICD10CMInferenceJobResponse
Stops an InferICD10CM inference job in progress.
423 |
# File 'sig/client.rbs', line 423
def stop_icd10cm_inference_job: (
|
#stop_phi_detection_job(params = {}) ⇒ Types::StopPHIDetectionJobResponse
Stops a protected health information (PHI) detection job in progress.
433 |
# File 'sig/client.rbs', line 433
def stop_phi_detection_job: (
|
#stop_rx_norm_inference_job(params = {}) ⇒ Types::StopRxNormInferenceJobResponse
Stops an InferRxNorm inference job in progress.
443 |
# File 'sig/client.rbs', line 443
def stop_rx_norm_inference_job: (
|
#stop_snomedct_inference_job(params = {}) ⇒ Types::StopSNOMEDCTInferenceJobResponse
Stops an InferSNOMEDCT inference job in progress.
453 |
# File 'sig/client.rbs', line 453
def stop_snomedct_inference_job: (
|
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1963 1964 1965 |
# File 'lib/aws-sdk-comprehendmedical/client.rb', line 1963 def waiter_names [] end |